/*
************************************************************************
*   FILE NAME...... WIN_TAB.C                                          *
*   DESCRIPTION.... Tables                                             *
*                                                                      *
*   TABLE NAME                                                         *
*       int  dir_tab[][2]                                              *
*       int  zm_tab[][4]                                               *
*       char *bdr_font[][6]                                            *
*       char attr_tab[MAX_COLOR][2]                                    *
*       char *errmsg[]                                                 *
*       unsigned char ctype_tab[][2][2]                                *
*                                                                      *
*   Copyright (c) 1987 by Doug J. Lieu                                 *
************************************************************************
*/

#include "stdio.h"
#include "win_stru.h"
#include "win_vd.h"
#include "win_kb.h"
#include "win_op.h"


int     smap_key = F6;                  /* key to display window stack map */
int     bdr_key = F7;                   /* key to display border types */
int     attr_key = F8;                  /* key to display attribute table */
int     tggl_key = F9;                  /* key to toggle control mode and enter mode */
int     stat_key = F10;                 /* key to display window's status */
int     brow_key = ESC;                 /* key to browse window's content after zoom or move */

char    *smap_str = "F6";
char    *bdr_str = "F7";
char    *attr_str = "F8";
char    *tggl_str = "F9";
char    *stat_str = "F10";
char    *brow_str = "ESC";


/* assign window initial status with cursor type normal, under   */
/* control mode, input file with attribute and save file flag on */

unsigned    init_status = (CSR_NORMAL | CTRL_MODE | LINE_MARK);


/* move direction table */
int dir_tab[][2] = {
        -1,  0,         /* UP         */
         1,  0,         /* DOWN       */
         0, -1,         /* LEFT       */
         0,  1,         /* RIGHT      */
        -1, -3,         /* UP_LEFT    */
        -1,  3,         /* UP_RIGHT   */
         1, -3,         /* DOWN_LEFT  */
         1,  3          /* DOWN_RIGHT */
};


/* zoom offset & size table */
int zm_tab[][4] = {
     /* top,bottom,left,right */
         -1,   1,  -1,   1,             /* ZOFFSET, run time definition: offset */
          0,  24,   0,  79,             /* ZPOS, run time definition: physical position */
          0,  24,   0,  79,             /* ZFULL */
         -1,   1,  -1,   1,             /* ZLARGE1 */
         -1,   1,  -3,   3,             /* ZLARGE2 */
          1,  -1,   1,  -1,             /* ZSMALL1 */
          1,  -1,   3,  -3,             /* ZSMALL2 */
         -1,   0,   0,   0,             /* ZTOP_U */
          1,   0,   0,   0,             /* ZTOP_D */
          0,  -1,   0,   0,             /* ZBTM_U */
          0,   1,   0,   0,             /* ZBTM_D */
          0,   0,  -1,   0,             /* ZLEFT_L */
          0,   0,   1,   0,             /* ZLEFT_R */
          0,   0,   0,  -1,             /* ZRIGHT_L */
          0,   0,   0,   1              /* ZRIGHT_R */
};


char *bdr_font[][6] = {
      /* up &    up &   down &  down &  top &   left &  */
      /* left    right  left    right   down    right   */

        "\xc9", "\xbb", "\xc8", "\xbc", "\xcd", "\xba",         /* double bar */
        "\xda", "\xbf", "\xc0", "\xd9", "\xc4", "\xb3",         /* single bar */
        "\xd6", "\xb7", "\xd3", "\xbd", "\xc4", "\xba",         /* single bar on top & bottom, double bar on two sides */
        "\xd5", "\xb8", "\xd4", "\xbe", "\xcd", "\xb3",         /* single bar on two sides, double bar on top & bottom */
        "*", "*", "*", "*", "*", "*",
        "#", "#", "#", "#", "#", "#",
        ".", ".", ".", ".", ".", ".",
        "$", "$", "$", "$", "$", "$",
        "@", "@", "@", "@", "@", "@",
        " ", " ", " ", " ", " ", " ",
        " ", " ", " ", " ", " ", " ",
        " ", " ", " ", " ", " ", " ",
        " ", " ", " ", " ", " ", " ",
        " ", " ", " ", " ", " ", " ",
        " ", " ", " ", " ", " ", " ",
        0
};


/* attribute name in mono mode */
char *mattr_name[] = {
        "Udln",                 /* 0x01  under line (Udln) */
        "Norm",                 /* 0x07  normal */
        "Hili",                 /* 0x08  intensity or bold */
        "Revs",                 /* 0x70  reverse video */
        "Blink"                 /* 0x80  blinking */
};


/* attribute name in color mode */
char *cattr_name[] = {
        "Black",                /*  0: BLK  */
        "Blue",                 /*  1: BLU  */
        "Green",                /*  2: GRN  */
        "Cyan",                 /*  3: CYN  */
        "Red",                  /*  4: RED  */
        "Magenta",              /*  5: MGT  */
        "Brown",                /*  6: BRN  */
        "White",                /*  7: WHT  */
        "Dgray",                /*  8: DGRY */
        "Lblue",                /*  9: LBLU */
        "Lgreen",               /* 10: LGRN */
        "Lcyan",                /* 11: LCYN */
        "Lred",                 /* 12: LRED */
        "Lmagenta",             /* 13: LMGT */
        "Yellow",               /* 14: YLW  */
        "Lwhite"                /* 15: LWHT */
};


/* attribute table for color and mono */
char attr_tab[][2] = {
    /* REGULAR  */      s_att(Black, White), Normal,
    /* NORMAL   */      s_att(Blue, White), Normal,
    /* REVERSE  */      s_att(White, Blue), Reverse,
    /* HILIGHT  */      s_att(Blue, Lwhite), Normal + Hilight,
    /* URGENT   */      s_att(Red, Yellow) + Blink, Normal + Hilight + Blink,
    /* HELP     */      s_att(Green, Lwhite), Normal,
    /* ERRMSG   */      s_att(Red, Black), Reverse,
    /* MESSAGE  */      s_att(Black, Yellow), Udln,
    /* BLK_BRN  */      s_att(Black, Brown) + Blink, Normal + Blink,
    /* BLK_CYN  */      s_att(Black, Cyan), Normal,
    /* BLK_GRN  */      s_att(Black, Green), Normal,
    /* BLK_LBLU */      s_att(Black, Lblue), Normal,
    /* BLK_RED  */      s_att(Black, Red), Normal,
    /* BLU_CYN  */      s_att(Blue, Cyan), Normal,
    /* BLU_GRN  */      s_att(Blue, Green), Reverse,
    /* BLU_LCYN */      s_att(Blue, Lcyan), Normal,
    /* BLU_LGRN */      s_att(Blue, Lgreen), Reverse,
    /* BLU_LRED */      s_att(Blue, Lred) + Blink, Normal + Blink,
    /* BLU_YLW  */      s_att(Blue, Yellow), Normal,
    /* BRN_BLK  */      s_att(Brown, Black), Normal,
    /* BRN_WHT  */      s_att(Brown, White), Normal,
    /* BRN_YLW  */      s_att(Brown, Yellow), Reverse,
    /* CYN_BLK  */      s_att(Cyan, Black), Normal,
    /* CYN_BLU  */      s_att(Cyan, Blue), Reverse,
    /* CYN_RED  */      s_att(Cyan, Red), Normal,
    /* GRN_BLU  */      s_att(Green, Blue), Udln,
    /* GRN_RED  */      s_att(Green, Red) + Blink, Normal + Blink,
    /* MAG_BLU  */      s_att(Magenta, Blue), Reverse,
    /* MGT_YLW  */      s_att(Magenta, Yellow), Normal,
    /* RED_BLK  */      s_att(Red, Black), Reverse,
    /* RED_CYN  */      s_att(Red, Cyan), Normal,
    /* RED_GRN  */      s_att(Red, Green), Normal,
    /* RED_LCYN */      s_att(Red, Lcyan), Normal,
    /* RED_LGRN */      s_att(Red, Lgreen), Normal + Hilight,
    /* RED_WHT  */      s_att(Red, White), Normal,
    /* WHT_BLK  */      s_att(White, Black), Reverse,
    /* WHT_BLU  */      s_att(White, Blue), Reverse,
    /* WHT_BRN  */      s_att(White, Brown), Normal,
    /* WHT_DGRY */      s_att(White, Dgray), Normal,
    /* WHT_MGT  */      s_att(White, Magenta), Normal,
    /* WHT_RED  */      s_att(White, Red), Reverse,
                        0
};


/* error messages, leading 'F': Fatal,  'f': Fatal and no title, 't': no title */
char *errmsg[] = {
    /*  0 - WIN_ERR   */      "  Invalid window number",
    /*  1 - INV_POS   */      "  Specified position will move the window out of the screen",
    /*  2 - NO_ROOM   */      "  No room for another window, can open up to 100 windows",
    /*  3 - ALLOC_ERR */      "  Cannot open the window, memory not enough",
    /*  4 - FREE_ERR  */      "F Cannot free the window. Hardware failure, fatal.",
    /*  5 - NO_MEMORY */      "  Memory not enough",
    /*  6 - INV_SIZE  */      "  Invalid window size",
    /*  7 - FSEEK_ERR */      "F fseek() error",
    /*  8 - FOPEN_ERR */      "  File open error",
    /*  9 - TOO_BIG   */      "  File too big to hold(64K max)",
    /* 10 - INV_RC    */      "  Invalid row and column",
    /* 11 - FREAD_ERR */      "F Read input file failed",
    /* 12 - DBGF_ERR  */      "  Cannot open debug output file",
    /* 13 - ACCESS_ERR*/      "  Cannot access input file",
    /* 14 - EMPTYFILE */      "  The file has size 0",
                              ""
};


/* cursor type */
unsigned char ctype_tab[][2][2] = {
         0,  0,  0,  0,         /* C_TOP      a dash at the top */
         0,  4,  0,  7,         /* C_THALF    half block at the top half */
         1,  0,  0, 13,         /* C_FULL     full block */
         3,  5,  3, 10,         /* C_MIDDLE   half block in the middle */
         4,  8,  7, 13,         /* C_BHALF    half block in the bottom half */
         5,  8, 10, 13,         /* C_QUARTER  quarter block in the bottom half */
         7,  0, 12, 13,         /* C_NORMAL   double dash at the bottom */
         8,  1, 13,  0,         /* C_QUOTE    a dash at the top and a dash at the bottom */
         8,  0, 13, 13,         /* C_DASH     a dash at the bottom */
         9,  0, 14,  0          /* C_BLANK    no cursor */
};
